;;; DO NOT MODIFY THIS FILE
(if (featurep 'semantic-autoloads) (error "Already loaded"))

;;;### (autoloads nil "_pkg" "semantic/_pkg.el")

(package-provide 'semantic :version 1.02 :type 'regular)

;;;***

;;;### (autoloads (semantic-create-imenu-index) "semantic-imenu" "semantic/semantic-imenu.el")

(autoload 'semantic-create-imenu-index "semantic-imenu" "\
Create an imenu index for any buffer which supports Semantic.
Uses the output of the Semantic Bovinator to create the index.
Optional argument STREAM STREAM is an optional stream of tokens used to create menus." nil nil)

;;;***

;;;### (autoloads (semantic-minor-mode) "semantic-mode" "semantic/semantic-mode.el")

(autoload 'semantic-minor-mode "semantic-mode" "\
Toggle semantic minor mode, a mode for tracking buffer parsing.
With prefix ARG, turn semantic minor mode on iff ARG is positive.

When in Semantic minor mode, the buffer will be parsed, and reparsed
during editing in small chunks, during idle time.

Semantic minor mode also allows modification of text properties on
tokens, highlighting them, or making functions read only.

\\<semantic-mode-map>
\\{semantic-mode-map}" t nil)

;;;***

;;;### (autoloads (semantic-bovinate-toplevel) "semantic" "semantic/semantic.el")

(autoload 'semantic-bovinate-toplevel "semantic" "\
Bovinate the entire current buffer.
If the optional argument CHECKCACHE is non-nil, then flush the cache iff
there has been a size change." nil nil)

;;;***

(provide 'semantic-autoloads)
